"""Protocol layer — message bus, A2A, MCP, and agent discovery."""

from nexus.protocol.a2a import A2AClient, A2AServer
from nexus.protocol.bus import MessageBus
from nexus.protocol.discovery import DiscoveryService
from nexus.protocol.mcp import MCPToolProvider

__all__ = [
    "MessageBus",
    "DiscoveryService",
    "A2AServer",
    "A2AClient",
    "MCPToolProvider",
]
